@@ -12,12 +12,25 @@ convert_tikz <- function(fig_block, article_dir) {
     if (!identical(caption_point, integer(0))) {
         fig_block$data[caption_point] <- ""
     }
+    caption_point <- which(grepl("\\\\caption\\{",fig_block$data))
+    if (!identical(caption_point, integer(0))) {
+        fig_block$data[caption_point] <- ""
+    }
+    M <- which(grepl("\\\\usepackage\\{Metafix\\}", fig_block$tikzlib))
+    if (! identical(M,integer(0))) {
+        fig_block$tikzlib[M] <- ""
+    }
+    A <- which(grepl("\\{tikz\\}", fig_block$tikzlib))
+    print(fig_block$tikzlib[A])
+    if (identical(A,integer(0))) {
+        fig_block$tikzlib[length(fig_block$tikzlib)] <- "\\usepackage{tikz}"
+    }
     tikz_picture_end_point <- which(grepl("\\\\end\\{tikzpicture\\}",fig_block$data))
     tikz_template <- c(
         "\\documentclass{standalone}",
         "\\usepackage{xcolor}",
         "\\usepackage{verbatim}",
-        "\\usepackage{tikz}",
+        #"\\usepackage{tikz}",
         "\\usepackage[T1]{fontenc}",
         "\\usepackage{graphics}",
         "\\usepackage{hyperref}",
@@ -29,16 +42,17 @@ convert_tikz <- function(fig_block, article_dir) {
         fig_block$tikzlib,
         "\\begin{document}",
         "\\nopagecolor",
-        fig_block$tikzstyle,
-        fig_block$data[2:tikz_picture_end_point],
+        #fig_block$tikzstyle,
+        fig_block$data[2:tikz_picture_end_point[length(tikz_picture_end_point)]],
         #fig_block$data,
         "\\end{document}"
     )
     tikz_file_name <- paste0(gsub(":","",fig_block$label),".tex")
+    tikz_template <- gsub(paste0("\\\\includegraphics\\{tikz/",gsub(":","",fig_block$label),".png\\}"),"",tikz_template)
     # convert the tex file into pdf
-    tikz_dir <- paste(article_dir,"tikz",sep="/")
-    tikz_path <- paste(tikz_dir,tikz_file_name,sep="/")
-    if(! dir.exists(tikz_dir)) {
+    tikz_dir <- paste(article_dir,"tikz",sep = "/")
+    tikz_path <- paste(tikz_dir,tikz_file_name,sep = "/")
+    if (!dir.exists(tikz_dir)) {
         dir.create(tikz_dir, showWarnings = FALSE)
     }
     # write the template
@@ -49,7 +63,7 @@ convert_tikz <- function(fig_block, article_dir) {
     tryCatch(tinytex::latexmk(tikz_path, engine = "pdflatex"),
              error = function(c) {
                  c$message <- paste0(c$message, " (in ", article_dir , ")")
-                 warning(c$message)
+                 message(c$message)
                  fig_block$compiled <- FALSE
              }
     )
@@ -61,21 +75,21 @@ convert_tikz <- function(fig_block, article_dir) {
     tryCatch(texor::convert_to_png(xfun::with_ext(tikz_path,"pdf")),
              error = function(c) {
                  c$message <- paste0(c$message, " (in ", article_dir , ")")
-                 warning(c$message)
+                 message(c$message)
                  fig_block$converted <- FALSE
              }
     )
     tikz_png_path <- xfun::with_ext(tikz_path,"png")
-    web_tikz_folder <- paste(article_dir,"web/tikz",sep="/")
+    web_tikz_folder <- paste(article_dir,"web/tikz",sep = "/")
     web_tikz_png_path <- paste0(web_tikz_folder,"/",tikz_png_file)
-    if(! dir.exists(web_tikz_folder)) {
-        dir.create(web_tikz_folder)
+    if (!dir.exists(web_tikz_folder)) {
+        suppressWarnings(dir.create(web_tikz_folder))
     }
     fig_block$copied <- TRUE
     tryCatch(file.copy(tikz_png_path,web_tikz_png_path),
              error = function(c) {
                  c$message <- paste0(c$message, " (in ", article_dir , ")")
-                 warning(c$message)
+                 message(c$message)
                  fig_block$copied <- FALSE
              }
     )
@@ -83,7 +97,7 @@ convert_tikz <- function(fig_block, article_dir) {
     tryCatch(insert_tikz_png(fig_block, article_dir),
              error = function(c) {
                  c$message <- paste0(c$message, " (in ", article_dir , ")")
-                 warning(c$message)
+                 message(c$message)
                  fig_block$included_as_png <- FALSE
              }
     )
@@ -137,7 +151,7 @@ extract_tikz_lib <- function(article_dir) {
         wrapper_lines <- readLines(wrapper_path)
     }
     else {
-        warning("LaTeX file not found !")
+        message("LaTeX file not found !")
         return(FALSE)
     }
     rjournal_line <- which(grepl("\\usepackage\\{RJournal\\}",wrapper_lines))
@@ -184,7 +198,7 @@ tikz_count <- function(article_dir, file_name) {
         raw_lines <- readLines(file_path)
     }
     else {
-        warning("LaTeX file not found !")
+        message("LaTeX file not found !")
         return(FALSE)
     }
     tikz_start_patt <- "\\\\begin\\{tikzpicture\\}"
@@ -256,14 +270,14 @@ article_has_tikz <- function(article_dir) {
     article_dir <- xfun::normalize_path(article_dir)
     # reads the complete file
     file_name <- get_texfile_name(article_dir)
-    if (file.exists(file.path(article_dir,file_name))){
+    if (file.exists(file.path(article_dir,file_name))) {
         src_file_data <- readLines(file.path(article_dir, file_name))
     }
     else {
-        warning("LaTeX file not found !")
+        message("LaTeX file not found !")
         return(FALSE)
     }
-    # all possibke values of tikz start points
+    # all possible values of tikz start points
     tikz_image_list <- which(grepl("^\\s*\\\\begin\\{tikzpicture",
                                    src_file_data))
     if (identical(tikz_image_list, integer(0))) {
@@ -283,11 +297,11 @@ article_has_tikz <- function(article_dir) {
 insert_tikz_png <- function(fig_block,article_dir) {
     article_dir <- xfun::normalize_path(article_dir)
     file_name <- get_texfile_name(article_dir)
-    if (file.exists(file.path(article_dir,file_name))){
+    if (file.exists(file.path(article_dir,file_name))) {
         raw_lines <- readLines(file.path(article_dir, file_name))
     }
     else {
-        warning("LaTeX file not found !")
+        message("LaTeX file not found !")
         return(FALSE)
     }
     file_path <- paste0(article_dir,"/",file_name)
@@ -298,9 +312,9 @@ insert_tikz_png <- function(fig_block,article_dir) {
     figure_starts <- c(figure_starts,alg_figure_starts)
     figure_starts <- sort(figure_starts)
     before_including_image <- raw_lines[1:figure_starts[fig_block$image_number]]
-    remaining_line <- raw_lines[((figure_starts[fig_block$image_number])+1):length(raw_lines)]
+    remaining_line <- raw_lines[((figure_starts[fig_block$image_number]) + 1):length(raw_lines)]
     if (!identical(which(grepl("\\\\includegraphics\\{tikz/",remaining_line)),integer(0))) {
-        warning("Image already included")
+        message("Image already included")
         return(TRUE)
     }
     include_png_line <- paste0("\\includegraphics{tikz/",gsub(":","",fig_block$label),".png}")
